[orca] More work on bgo 608149 - Orca's caret navigation for Firefox is broken effective the 30th Sept buil



commit ba68863c9cf08485c6ba40396f72217f3c103abe
Author: Joanmarie Diggs <joanmarie diggs gmail com>
Date:   Sat Feb 13 14:46:00 2010 -0500

    More work on bgo 608149 - Orca's caret navigation for Firefox is broken effective the 30th Sept build of FF 3.6
    
    This gives Thunderbird a separate grabFocusOnAncestor setting because
    we cannot count on the versions of Gecko being the same between these
    apps.

 src/orca/scripts/apps/Thunderbird/script.py        |   13 ++++++++++++-
 .../scripts/apps/Thunderbird/script_settings.py    |    5 +++++
 2 files changed, 17 insertions(+), 1 deletions(-)
---
diff --git a/src/orca/scripts/apps/Thunderbird/script_settings.py b/src/orca/scripts/apps/Thunderbird/script_settings.py
index b7c6d67..8d59e00 100644
--- a/src/orca/scripts/apps/Thunderbird/script_settings.py
+++ b/src/orca/scripts/apps/Thunderbird/script_settings.py
@@ -28,3 +28,8 @@ __license__   = "LGPL"
 # when a message is first loaded.
 #
 sayAllOnLoad = False
+
+# Whether we should grab focus on a focusable ancestor when setting
+# the caret position. See bug 608149.
+#
+grabFocusOnAncestor = True



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/orca/scripts/apps/Thunderbird/script.py b/src/orca/scripts/apps/Thunderbird/script.py
index 0266edc..52352c6 100644
--- a/src/orca/scripts/apps/Thunderbird/script.py
+++ b/src/orca/scripts/apps/Thunderbird/script.py
@@ -102,6 +102,13 @@ class Script(Gecko.Script):
         gtk.ToggleButton.set_active(self.sayAllOnLoadCheckButton,
                                     script_settings.sayAllOnLoad)
 
+        # We need to maintain a separate setting for grabFocusOnAncestor
+        # because the version of Gecko used by the Thunderbird might be
+        # different from that used by Firefox. See bug 608149.
+        #
+        gtk.ToggleButton.set_active(self.grabFocusOnAncestorCheckButton,
+                                    script_settings.grabFocusOnAncestor)
+
         return vbox
 
     def setAppPreferences(self, prefs):
@@ -114,13 +121,17 @@ class Script(Gecko.Script):
 
         Gecko.Script.setAppPreferences(self, prefs)
 
         # Write the Thunderbird specific setting.
         #
         prefix = "orca.scripts.apps.Thunderbird.script_settings"
         value = self.sayAllOnLoadCheckButton.get_active()
         prefs.writelines("%s.sayAllOnLoad = %s\n" % (prefix, value))
         script_settings.sayAllOnLoad = value
 
+        value = self.grabFocusOnAncestorCheckButton.get_active()
+        prefs.writelines("%s.grabFocusOnAncestor = %s\n" % (prefix, value))
+        script_settings.grabFocusOnAncestor = value
+
     def _debug(self, msg):
         """ Convenience method for printing debug messages
         """
@@ -114,13 +121,17 @@ class Script(Gecko.Script):
         Gecko.Script.setAppPreferences(self, prefs)
 
-        # Write the Thunderbird specific setting.
+        # Write the Thunderbird specific settings.
         #
         prefix = "orca.scripts.apps.Thunderbird.script_settings"